@@ -1,7 +1,7 @@
-/* $Id: data.c,v 1.2 2007/08/21 10:16:06 dhartmei Exp $ */
+/* $Id: data.c,v 1.3 2010/05/27 10:22:38 dhartmei Exp $ */
 
 /*
- * Copyright (c) 2002-2006, Daniel Hartmeier
+ * Copyright (c) 2002-2010, Daniel Hartmeier
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -30,7 +30,7 @@
  *
  */
 
-static const char rcsid[] = "$Id: data.c,v 1.2 2007/08/21 10:16:06 dhartmei Exp $";
+static const char rcsid[] = "$Id: data.c,v 1.3 2010/05/27 10:22:38 dhartmei Exp $";
 
 #include <sys/types.h>
 #include <netinet/in.h>
@@ -666,3 +666,68 @@ next:
 		    deleted, seen);
 	return (0);
 }
+
+int
+data_copy(const char *filename)
+{
+	BTREEINFO bti2;
+	DB *db2;
+	int r;
+	unsigned count = 0;
+
+	if (debug > 0)
+		printf("data_copy: creating %s\n", filename);
+	memset(&bti2, 0, sizeof(bti2));
+	db2 = dbopen(filename, O_CREAT|O_EXLOCK|O_RDWR, 0600, DB_BTREE, &bti2);
+	if (db2 == NULL) {
+		fprintf(stderr, "data_copy: dbopen: %s: %s\n", filename,
+		    strerror(errno));
+		return (1);
+	}
+
+	r = db->seq(db, &dbk, &dbd, R_FIRST);
+	if (r < 0) {
+		fprintf(stderr, "data_copy: db->seq(R_FIRST) failed: %s\n",
+		    strerror(errno));
+		return (1);
+	}
+	do {
+		if (dbk.data == NULL || dbk.size != sizeof(k)) {
+			fprintf(stderr, "data_copy: invalid record: "
+			    "dbk.size %u (%u)\n", (unsigned)dbk.size,
+			    (unsigned)sizeof(k));
+		} else if (dbd.data == NULL || dbd.size !=
+		    (ntohs(((struct key *)dbk.data)->level) == MAX_LEVEL ?
+		    sizeof(l) : sizeof(v))) {
+			fprintf(stderr, "data_copy: invalid record: level %u, "
+			    "dbd.size %u (%u, %u)\n",
+			    (unsigned)ntohs(((struct key *)dbk.data)->level),
+			    (unsigned)dbd.size, (unsigned)sizeof(l),
+			    (unsigned)sizeof(v));
+		} else if (db2->put(db2, &dbk, &dbd, 0)) {
+			fprintf(stderr, "data_copy: db->put: %s\n",
+			    strerror(errno));
+			break;
+		} else {
+			count++;
+			if (debug > 1 && count % 10000 == 0)
+				printf(" %u", count);
+		}
+		r = db->seq(db, &dbk, &dbd, R_NEXT);
+		if (r < 0)
+			fprintf(stderr, "data_copy: db->seq(R_NEXT) failed: "
+			    "%s\n", strerror(errno));
+	} while (!r);
+	if (debug > 1)
+		printf("\n");
+
+	if (db2->sync(db2, 0))
+		fprintf(stderr, "data_copy: dbsync: %s: %s\n", filename,
+		    strerror(errno));
+	if (db2->close(db2))
+		fprintf(stderr, "data_copy: dbclose: %s: %s\n", filename,
+		    strerror(errno));
+	if (debug > 0)
+		printf("data_copy: %u records copied\n", count);
+	return (0);
+}
