@@ -1,7 +1,7 @@
-/* $Id: pfstat.c,v 1.1.1.1 2007/01/11 16:01:58 dhartmei Exp $ */
+/* $Id: pfstat.c,v 1.2 2010/05/27 10:22:38 dhartmei Exp $ */
 
 /*
- * Copyright (c) 2002-2006, Daniel Hartmeier
+ * Copyright (c) 2002-2010, Daniel Hartmeier
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -30,7 +30,7 @@
  *
  */
 
-static const char rcsid[] = "$Id: pfstat.c,v 1.1.1.1 2007/01/11 16:01:58 dhartmei Exp $";
+static const char rcsid[] = "$Id: pfstat.c,v 1.2 2010/05/27 10:22:38 dhartmei Exp $";
 
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -117,7 +117,7 @@ usage(void)
 	extern char *__progname;
 
 	fprintf(stderr, "usage: %s [-v] [-c config] [-d data] [-r host[:port]] "
-	    "[-p] [-q] [-t days[:days]]\n", __progname);
+	    "[-p] [-q] [-t days[:days]] [-f file]\n", __progname);
 	exit(1);
 }
 
@@ -126,6 +126,7 @@ main(int argc, char *argv[])
 {
 	const char *configfn = "/etc/pfstat.conf";
 	const char *datafn = "/var/db/pfstat.db";
+	const char *fixfn = NULL;
 	const char *addr = NULL;
 	const char *serv = "9999";
 	int ch, query = 0, draw = 0, trunc = 0, i;
@@ -133,7 +134,7 @@ main(int argc, char *argv[])
 	struct matrix *matrices = NULL, *m;
 	struct graph *g;
 
-	while ((ch = getopt(argc, argv, "c:d:pqr:t:v")) != -1) {
+	while ((ch = getopt(argc, argv, "c:d:f:pqr:t:v")) != -1) {
 		switch (ch) {
 		case 'c':
 			configfn = optarg;
@@ -141,6 +142,9 @@ main(int argc, char *argv[])
 		case 'd':
 			datafn = optarg;
 			break;
+		case 'f':
+			fixfn = optarg;
+			break;
 		case 'p':
 			draw = 1;
 			break;
@@ -193,7 +197,7 @@ main(int argc, char *argv[])
 	}
 	if (argc != optind)
 		usage();
-	if (!query && !draw && !trunc)
+	if (!query && !draw && !trunc && !fixfn)
 		usage();
 
 	if (parse_config(configfn, &matrices))
@@ -338,6 +342,15 @@ main(int argc, char *argv[])
 
 	}
 
+	if (fixfn) {
+		if (debug)
+			printf("fixing database %s to %s\n", datafn, fixfn);
+		if (data_copy(fixfn)) {
+			fprintf(stderr, "main: data_copy() failed\n");
+			return (1);
+		}
+	}
+
 	data_close();
 	return (0);
 }
