@@ -1,4 +1,4 @@
-/* $Id: pfstatd.c,v 1.1.1.1 2007/01/11 16:01:58 dhartmei Exp $ */
+/* $Id: pfstatd.c,v 1.2 2008/06/10 17:16:46 dhartmei Exp $ */
 
 /*
  * Copyright (c) 2002-2006, Daniel Hartmeier
@@ -30,7 +30,7 @@
  *
  */
 
-static const char rcsid[] = "$Id: pfstatd.c,v 1.1.1.1 2007/01/11 16:01:58 dhartmei Exp $";
+static const char rcsid[] = "$Id: pfstatd.c,v 1.2 2008/06/10 17:16:46 dhartmei Exp $";
 
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -39,6 +39,7 @@ static const char rcsid[] = "$Id: pfstatd.c,v 1.1.1.1 2007/01/11 16:01:58 dhartm
 #include <errno.h>
 #include <fcntl.h>
 #include <pwd.h>
+#include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -97,6 +98,7 @@ main(int argc, char *argv[])
 	}
 	if (argc != optind)
 		usage();
+	signal(SIGPIPE, SIG_IGN);
 	if ((fdp = open("/dev/pf", O_RDONLY)) < 0) {
 		fprintf(stderr, "open: /dev/pf: %s\n", strerror(errno));
 		return (1);
